Config

Struct Config 

pub struct Config<'a> {
    pub client_id: i64,
    pub client_secret: &'a SecretString,
}
The configuration for the Strava API client.

Fields

client_id: i64

The client ID, assigned by Strava in SettingsMy API Application.

client_secret: &'a SecretString

The client secret, assigned by Strava in SettingsMy API Application.

Implementations

Source

impl Config<'_>

pub fn login_url(&self, redirect: &str) -> Result<Url>

Returns the URL that can be used to obtain an authorization token.

Users have to open the URL in their web browser, login to Strava and authorize the application. They are then redirected to the given URL, e. g. http://localhost/exchange_token, and have to extract the authroization token from the code query field of the redirected URL. This token can then be used for the initial API login with Api::login.