State

Struct State 

pub struct State {
    pub access_token: String,
    pub refresh_token: String,
    pub expiration: DateTime<Local>,
}
The state of the Strava API client.

Callers should persist this state between API invocations to make sure that authorized access is working properly. The state is unique for a user, so multi-user applications should maintain one instance per user.

Fields

access_token: String

The last access token received from the Strava API.

refresh_token: String

The refresh token that was received with the stored access token.

expiration: DateTime<Local>

The expiration time of the stored access token.