pub struct UploadOptions<'a> {
pub data_type: Option<DataType>,
pub name: Option<&'a str>,
pub description: Option<&'a str>,
pub sport_type: Option<&'a str>,
}Expand description
The options for a file upload.
Fields
data_type: Option<DataType>The data type of the file.
If not set, it is automatically determined from the file extension.
name: Option<&'a str>The name of the activity.
If not set, it is set automatically by Strava.
description: Option<&'a str>The description of the activity.
sport_type: Option<&'a str>The sport type of the activity.
If not set, it is automatically determined by Strava.